import { useState } from 'react';
import { useLocation } from 'wouter';
import { useTranslation } from 'react-i18next';
import { useQuery, useMutation } from '@tanstack/react-query';
import { Button } from '@/components/ui/button';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';
import { Input } from '@/components/ui/input';
import { Dialog, DialogContent, DialogHeader, DialogTitle, DialogTrigger } from '@/components/ui/dialog';
import { ArrowLeft, Plus, CreditCard, DollarSign, Loader2, Wallet, TrendingUp, History, Shield, Info, Send } from 'lucide-react';
import { useAuth } from '@/contexts/AuthContext';
import { useToast } from '@/hooks/use-toast';
import { apiRequest, queryClient } from '@/lib/queryClient';
import { OfficialPayPalButton } from '@/components/OfficialPayPalButton';
import { PaymentSummary, calculateTotalWithFees } from '@/components/PaymentSummary';

import type { WalletTransaction, ServiceFee } from '@shared/schema';
import { LoadingScreen } from '@/components/LoadingScreen';
import { Logo } from '@/components/Logo';

export default function WalletPage() {
  const [, setLocation] = useLocation();
  const { t } = useTranslation();
  const { user } = useAuth();
  const { toast } = useToast();
  const [showAddFunds, setShowAddFunds] = useState(false);
  const [amount, setAmount] = useState('');

  const { data: walletTransactions, isLoading: transactionsLoading } = useQuery<{ transactions: WalletTransaction[] }>({
    queryKey: ['/api/wallet/transactions'],
    enabled: !!user,
  });

  const { data: serviceFees } = useQuery<{ serviceFees: ServiceFee[] }>({
    queryKey: ['/api/admin/service-fees'],
    enabled: !!user,
  });

  const addFundsMutation = useMutation({
    mutationFn: async (data: { amount: string; paypalOrderId: string }) => 
      apiRequest('/api/wallet/add-funds', 'POST', data),
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/wallet/transactions'] });
      queryClient.invalidateQueries({ queryKey: ['/api/auth/login'] });
      setShowAddFunds(false);
      setAmount('');
      toast({
        title: t('wallet.fundsAddedSuccess'),
        description: t('wallet.fundsAddedDesc', { amount }),
      });
    },
    onError: () => {
      toast({
        title: t('common.error'),
        description: t('wallet.addFundsError'),
        variant: 'destructive',
      });
    },
  });

  const predefinedAmounts = ['10', '25', '50', '100'];

  if (!user) {
    return <LoadingScreen />;
  }

  return (
    <div className="min-h-screen bg-gray-50">
      {/* Header */}
      <header className="bg-[hsl(184,100%,14%)] text-white sticky top-0 z-40">
        <div className="px-4 py-3">
          <div className="flex items-center space-x-4">
            <Button
              variant="ghost"
              size="sm"
              onClick={() => setLocation('/dashboard')}
              className="text-white hover:bg-white/10"
            >
              <ArrowLeft className="h-4 w-4" />
            </Button>
            <Logo size="sm" />
            <div className="flex-1">
              <h1 className="text-xl font-bold">{t('wallet.myWallet')}</h1>
            </div>
          </div>
        </div>
      </header>

      <div className="p-4 space-y-6">
        {/* Wallet Balance Card */}
        <Card className="bg-gradient-to-r from-[hsl(184,100%,14%)] to-[hsl(327,100%,55%)] text-white">
          <CardContent className="p-6">
            <div className="flex items-center justify-between">
              <div>
                <p className="text-sm opacity-90">{t('wallet.yourBalance')}</p>
                <p className="text-3xl font-bold">${user?.walletBalance || '0.00'}</p>
              </div>
              <Wallet className="h-12 w-12 opacity-75" />
            </div>
            
            {/* Wallet Statistics */}
            <div className="mt-4 flex space-x-4">
              <div className="flex-1">
                <p className="text-gray-300 text-xs">{t('wallet.thisMonth')}</p>
                <p className="text-lg font-semibold">$0.00</p>
              </div>
              <div className="flex-1">
                <p className="text-gray-300 text-xs">{t('wallet.topupsSent')}</p>
                <p className="text-lg font-semibold">0</p>
              </div>
              <div className="flex-1">
                <p className="text-gray-300 text-xs">{t('wallet.rewardPoints')}</p>
                <p className="text-lg font-semibold">{user?.loyaltyPoints || 0}</p>
              </div>
            </div>

            <div className="mt-4 flex space-x-3">
              <Dialog open={showAddFunds} onOpenChange={setShowAddFunds}>
                <DialogTrigger asChild>
                  <Button className="bg-white text-[hsl(184,100%,14%)] hover:bg-gray-100 flex-1">
                    <Plus className="h-4 w-4 mr-2" />
                    {t('wallet.addFunds')}
                  </Button>
                </DialogTrigger>
              </Dialog>
              <Button 
                onClick={() => setLocation('/send-topup')}
                className="bg-green-600 hover:bg-green-700 text-white flex-1"
              >
                <Send className="h-4 w-4 mr-2" />
                {t('wallet.sendTopUp')}
              </Button>
            </div>
          </CardContent>
        </Card>



        {/* Recent Transactions */}
        <Card>
          <CardHeader>
            <CardTitle className="flex items-center text-[hsl(184,100%,14%)]">
              <History className="h-5 w-5 mr-2" />
{t('wallet.recentTransactions')}
            </CardTitle>
          </CardHeader>
          <CardContent>
            {transactionsLoading ? (
              <div className="flex items-center justify-center py-8">
                <Loader2 className="h-8 w-8 animate-spin text-[hsl(327,100%,55%)]" />
              </div>
            ) : !walletTransactions?.transactions?.length ? (
              <div className="text-center py-8 text-gray-500">
                <DollarSign className="h-12 w-12 mx-auto mb-3 opacity-50" />
                <p>{t('wallet.noTransactions')}</p>
                <p className="text-sm">{t('wallet.startFirstDeposit')}</p>
              </div>
            ) : (
              <div className="space-y-3">
                {walletTransactions.transactions.map((transaction) => (
                  <div key={transaction.id} className="flex items-center justify-between p-3 rounded-lg border">
                    <div className="flex items-center space-x-3">
                      <div className={`w-8 h-8 rounded-full flex items-center justify-center ${
                        transaction.type === 'deposit' ? 'bg-green-100' : 'bg-red-100'
                      }`}>
                        {transaction.type === 'deposit' ? (
                          <TrendingUp className="h-4 w-4 text-green-600" />
                        ) : (
                          <DollarSign className="h-4 w-4 text-red-600" />
                        )}
                      </div>
                      <div>
                        <p className="font-medium">
                          {transaction.type === 'deposit' ? t('wallet.deposit') : t('wallet.withdrawal')}
                        </p>
                        <p className="text-xs text-gray-500">
                          {transaction.description || t('wallet.noDescription')}
                        </p>
                        <p className="text-xs text-gray-400">
                          {transaction.createdAt ? new Date(transaction.createdAt.toString()).toLocaleDateString('en-US') : t('wallet.dateNotAvailable')}
                        </p>
                      </div>
                    </div>
                    <span className={`font-bold ${
                      transaction.type === 'deposit' ? 'text-green-600' : 'text-red-600'
                    }`}>
                      {transaction.type === 'deposit' ? '+' : '-'}${transaction.amount}
                    </span>
                  </div>
                ))}
              </div>
            )}
          </CardContent>
        </Card>
      </div>

      {/* Add Funds Dialog */}
      <Dialog open={showAddFunds} onOpenChange={setShowAddFunds}>
        <DialogContent className="sm:max-w-md max-h-[90vh] overflow-y-auto">
          <DialogHeader>
            <DialogTitle className="text-[hsl(184,100%,14%)]">{t('wallet.addFundsToWallet')}</DialogTitle>
          </DialogHeader>
          <div className="space-y-4 pb-8">
            <div>
              <label className="text-sm font-medium">{t('wallet.amountUSD')}</label>
              <Input
                type="number"
                value={amount}
                onChange={(e) => setAmount(e.target.value)}
                placeholder={t('wallet.enterAmount')}
                min="1"
                max="1000"
                className="mt-1"
              />
            </div>

            <div>
              <label className="text-sm font-medium mb-2 block">{t('wallet.quickSelect')}</label>
              <div className="grid grid-cols-4 gap-2">
                {predefinedAmounts.map((preAmount) => (
                  <Button
                    key={preAmount}
                    variant="outline"
                    size="sm"
                    onClick={() => setAmount(preAmount)}
                    className={amount === preAmount ? 'border-[hsl(327,100%,55%)] text-[hsl(327,100%,55%)]' : ''}
                  >
                    ${preAmount}
                  </Button>
                ))}
              </div>
            </div>

            {amount && parseFloat(amount) >= 1 && serviceFees?.serviceFees && (
              <>
                <PaymentSummary 
                  amount={amount} 
                  type="wallet"
                />
                
                <div className="border-t pt-4 mb-8">
                  <div className="bg-white rounded-lg p-6 border shadow-sm">
                    <h3 className="text-lg font-medium mb-4 text-center text-[hsl(184,100%,14%)]">
                      {t('wallet.payWithPayPal')}
                    </h3>
                    <div className="min-h-[80px] w-full">
                      <OfficialPayPalButton
                        amount={calculateTotalWithFees(amount, 'wallet', serviceFees?.serviceFees).toFixed(2)}
                        currency="USD"
                        onSuccess={(details: any) => {
                          console.log('Payment successful:', details);
                          if (details.id) {
                            addFundsMutation.mutate({
                              amount,
                              paypalOrderId: details.id
                            });
                          }
                        }}
                        onError={(error: any) => {
                          console.error('Payment error:', error);
                          toast({
                            title: t('wallet.paymentError'),
                            description: t('wallet.paymentErrorDesc'),
                            variant: 'destructive',
                          });
                        }}
                        onCancel={(data: any) => {
                          console.log('Payment cancelled:', data);
                          toast({
                            title: t('wallet.paymentCancelled'),
                            description: t('wallet.paymentCancelledDesc'),
                          });
                        }}
                      />
                    </div>
                  </div>
                </div>
              </>
            )}
          </div>
        </DialogContent>
      </Dialog>
    </div>
  );
}